@@ -45,7 +45,7 @@ DiaryElement::DiaryElement() : NamedElement( "" ) {}
 DiaryElement::DiaryElement( Diary* const ptr2diary,
                             const Ustring& name,
                             ElemStatus status )
-:   NamedElement( name ), m_ptr2diary( ptr2diary ),
+:   NamedElement( name ), m_p2diary( ptr2diary ),
     m_status( status ),
     m_id( ptr2diary ? ptr2diary->create_new_id( this ) :  DEID_UNSET )
 {
@@ -54,7 +54,7 @@ DiaryElement::DiaryElement( Diary* const ptr2diary,
 }
 
 DiaryElement::DiaryElement( Diary* const ptr2diary, DEID id, ElemStatus status )
-:   NamedElement( "" ), m_ptr2diary( ptr2diary ), m_status( status ), m_id( id )
+:   NamedElement( "" ), m_p2diary( ptr2diary ), m_status( status ), m_id( id )
 {
     if( FLAG_ALLOCATE_GUI_FOR_DIARY )
         m_list_data = new ListData;
@@ -62,8 +62,8 @@ DiaryElement::DiaryElement( Diary* const ptr2diary, DEID id, ElemStatus status )
 
 DiaryElement::~DiaryElement()
 {
-    if( m_ptr2diary != nullptr )
-        m_ptr2diary->erase_id( m_id );
+    if( m_p2diary != nullptr )
+        m_p2diary->erase_id( m_id );
 
     if( m_list_data != nullptr )
         delete m_list_data;
@@ -174,6 +174,12 @@ Paragraph::has_tag( const Entry* tag ) const
     return( m_tags.find( tag->get_name() ) != m_tags.end() );
 }
 
+bool
+Paragraph::has_tag_planned( const Entry* tag ) const
+{
+    return( m_tags_planned.find( tag->get_name() ) != m_tags.end() );
+}
+
 bool
 Paragraph::has_tag_broad( const Entry* tag ) const
 {
@@ -210,7 +216,7 @@ Paragraph::get_value_for_tag( const Entry* tag, int& count ) const
 Value
 Paragraph::get_value_planned_for_tag( const Entry* tag, int& count ) const
 {
-    if( !tag || !has_tag( tag ) )
+    if( !tag || !has_tag_planned( tag ) )
         return 0.0;
     else
     {
@@ -222,7 +228,7 @@ Paragraph::get_value_planned_for_tag( const Entry* tag, int& count ) const
 Value
 Paragraph::get_value_remaining_for_tag( const Entry* tag, int& count ) const
 {
-    if( !tag || !has_tag( tag ) )
+    if( !tag || !has_tag_planned( tag ) )
         return 0.0;
     else
     {
@@ -253,7 +259,7 @@ Paragraph::get_value_planned_for_tag( const ChartData* chart_data, int& count )
     if( chart_data->para_filter_tag && !has_tag_broad( chart_data->para_filter_tag ) )
         return 0.0;
     else
-    if( !has_tag( chart_data->tag ) )
+    if( !has_tag_planned( chart_data->tag ) )
         return 0.0;
     else
     {
@@ -646,7 +652,7 @@ Theme::Theme( Diary* const d, const Ustring& name, const Theme* theme )
 bool
 Theme::is_default() const
 {
-    return( m_ptr2diary ? ( m_ptr2diary->get_theme_default() == this ) : false );
+    return( m_p2diary && m_p2diary->get_theme_default()->is_equal_to( this ) );
 }
 
 void
@@ -739,14 +745,14 @@ ChartData::get_as_string() const
             chart_def += "Gym\n";
             break;
         case TAG_VALUE_ENTRY: // tag value
-            chart_def += STR::compose( "Gyt", tag ? tag->get_id() : DEID_UNSET, '\n' ) ;
+            chart_def += STR::compose( "Gyt", tag ? tag->get_id() : DEID_UNSET, '\n' );
             chart_def += STR::compose( "Gp", para_filter_tag ? para_filter_tag->get_id() :
-                                                               DEID_UNSET, '\n' ) ;
+                                                               DEID_UNSET, '\n' );
             break;
         case TAG_VALUE_PARA: // tag value
-            chart_def += STR::compose( "Gyp", tag ? tag->get_id() : DEID_UNSET, '\n' ) ;
+            chart_def += STR::compose( "Gyp", tag ? tag->get_id() : DEID_UNSET, '\n' );
             chart_def += STR::compose( "Gp", para_filter_tag ? para_filter_tag->get_id() :
-                                                               DEID_UNSET, '\n' ) ;
+                                                               DEID_UNSET, '\n' );
             break;
     }
 
@@ -806,30 +812,30 @@ ChartData::set_from_string( const Ustring& chart_def )
                         type |= MAP_PATH_LENGTH;
                         break;
                     case 't':   // tag value
-                        type |= ChartData::TAG_VALUE_ENTRY;
-                        tag = m_ptr2diary->get_entry_by_id( std::stoul( line.substr( 3 ) ) );
+                        type |= TAG_VALUE_ENTRY;
+                        tag = m_p2diary->get_entry_by_id( std::stoul( line.substr( 3 ) ) );
                         break;
                     case 'p':   // tag value
-                        type |= ChartData::TAG_VALUE_PARA;
-                        tag = m_ptr2diary->get_entry_by_id( std::stoul( line.substr( 3 ) ) );
+                        type |= TAG_VALUE_PARA;
+                        tag = m_p2diary->get_entry_by_id( std::stoul( line.substr( 3 ) ) );
                         break;
                 }
                 break;
             }
             case 'p': // para filter tag
-                para_filter_tag = m_ptr2diary->get_entry_by_id( std::stoul( line.substr( 2 ) ) );
+                para_filter_tag = m_p2diary->get_entry_by_id( std::stoul( line.substr( 2 ) ) );
                 break;
             case 'f':   // filter
-                filter = m_ptr2diary->get_filter( line.substr( 2 ) );
+                filter = m_p2diary->get_filter( line.substr( 2 ) );
                 break;
             case 'o':
                 if( line[ 2 ] == 'T' )
-                    type |= ChartData::TAGGED_ONLY;
+                    type |= TAGGED_ONLY;
 
                 switch( line[ 3 ] )
                 {
-                    case 'Y': type |= ChartData::UNDERLAY_PREV_YEAR; break;
-                    case 'P': type |= ChartData::UNDERLAY_PLANNED; break;
+                    case 'Y': type |= UNDERLAY_PREV_YEAR; break;
+                    case 'P': type |= UNDERLAY_PLANNED; break;
                 }
                 switch( line[ 4 ] )
                 {
@@ -1719,11 +1725,10 @@ TableData::populate_lines()
     // total line & sort column
     m_line_total = new TableLine;
     int i_col{ 0 };
-    TableColumn* col_sort{ nullptr };
     for( auto& col : m_columns )
     {
         if( i_col == m_i_col_sort )
-            col_sort = col;
+            sort_lines( col );
 
         if( col->is_numeric() )
         {
@@ -1735,14 +1740,32 @@ TableData::populate_lines()
         i_col++;
     }
 
+    delete fc;
+}
+
+void
+TableData::sort_lines( TableColumn* col_sort ) {
+    if( col_sort == nullptr )
+    {
+        int i_col = 0;
+        for( auto& col : m_columns )
+        {
+            if( i_col == m_i_col_sort )
+            {
+                col_sort = col;
+                break;
+            }
+            else
+                i_col++;
+        }
+    }
+
     m_lines_sorted = new SetTableLines( TableLineComparator( m_i_col_sort,
                                                              col_sort,
                                                              m_f_sort_desc ) );
 
     for( auto& kv_line : m_lines_unsorted )
         m_lines_sorted->emplace( kv_line.second );
-
-    delete fc;
 }
 
 Ustring
