@@ -67,7 +67,7 @@ Entry::get_as_skvvec() const
 Entry*
 Entry::get_parent() const
 {
-    return( m_ptr2diary->get_entry_by_date( m_date.get_parent(), true ) );
+    return( m_p2diary->get_entry_by_date( m_date.get_parent(), true ) );
 }
 
 int
@@ -77,7 +77,7 @@ Entry::get_child_count() const
 
     if( m_date.get_level() < 3 )
     {
-        auto&  entries  { m_ptr2diary->get_entries() };
+        auto&  entries  { m_p2diary->get_entries() };
         auto&& it_entry { entries.find( this->get_date_t() ) };
 
         if( it_entry == entries.begin() || it_entry == entries.end() )
@@ -111,7 +111,7 @@ Entry::get_descendants() const
 
     if( is_ordinal() && m_date.get_level() < 3 )
     {
-        auto&  entries  { m_ptr2diary->get_entries() };
+        auto&  entries  { m_p2diary->get_entries() };
         auto&& it_entry { entries.find( this->get_date_t() ) };
 
         if( it_entry == entries.begin() || it_entry == entries.end() )
@@ -143,7 +143,7 @@ Entry::get_descendant_depth() const
         return 0;
 
     int    count{ 0 };
-    auto&  entries{ m_ptr2diary->get_entries() };
+    auto&  entries{ m_p2diary->get_entries() };
     auto&& it_entry{ entries.find( this->get_date_t() ) };
 
     if( it_entry == entries.begin() || it_entry == entries.end() )
@@ -437,7 +437,7 @@ Entry::get_completion() const
 double
 Entry::get_completed() const
 {
-    Entry* tag_comp{ m_ptr2diary->get_completion_tag() };
+    Entry* tag_comp{ m_p2diary->get_completion_tag() };
 
     if( tag_comp == nullptr )
         return 0.0;
@@ -448,7 +448,7 @@ Entry::get_completed() const
 double
 Entry::get_workload() const
 {
-    Entry* tag_comp{ m_ptr2diary->get_completion_tag() };
+    Entry* tag_comp{ m_p2diary->get_completion_tag() };
 
     if( tag_comp == nullptr )
         return 0.0;
@@ -489,8 +489,8 @@ Entry::set_text( const Ustring& text )
     update_name();
     update_todo_status();
 
-    if( m_ptr2diary && get_type() != ET_CHAPTER )
-        m_ptr2diary->update_entry_name( this );
+    if( m_p2diary && get_type() != ET_CHAPTER )
+        m_p2diary->update_entry_name( this );
 }
 
 void
@@ -756,13 +756,13 @@ std::string
 Entry::get_lang_final() const
 {
     return m_option_lang == LANG_INHERIT_DIARY ?
-            m_ptr2diary->get_lang() : m_option_lang;
+            m_p2diary->get_lang() : m_option_lang;
 }
 
 const Theme*
 Entry::get_theme() const
 {
-    return( m_p2theme ? m_p2theme : m_ptr2diary->get_theme_default() );
+    return( m_p2theme ? m_p2theme : m_p2diary->get_theme_default() );
 }
 
 bool
@@ -856,11 +856,14 @@ Entry::get_value_remaining_for_tag( const Entry* tag, bool f_average ) const
 Entry*
 Entry::get_sub_tag_first( const Entry* tag ) const
 {
-    for( auto& para : m_paragraphs )
+    if( tag != nullptr )
     {
-        auto sub_tag{ para->get_sub_tag_first( tag ) };
-        if( sub_tag )
-            return sub_tag;
+        for( auto& para : m_paragraphs )
+        {
+            auto sub_tag{ para->get_sub_tag_first( tag ) };
+            if( sub_tag )
+                return sub_tag;
+        }
     }
 
     return nullptr;
