@@ -33,11 +33,11 @@
 using namespace LIFEO;
 
 // STATIC MEMBERS
-const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "2.0.0"
+const char                      Lifeograph::PROGRAM_VERSION_STRING[] = "2.0.1"
 #if LIFEOGRAPH_DEBUG_BUILD || defined( LIFEOGRAPH_BETA_STAGE )
         "\n" BUILD_TIMESTAMP
 #endif
-        "\n\"processing data is a delicious experience\"";
+        "\n\"let no one ignorant of geometry enter your heart\"";
 
 
 Lifeograph*                     Lifeograph::p;
