@@ -352,7 +352,7 @@ EntryParserPango::add_diary_cover()
     if( m_opt_use_theme_font )
         m_font = ThemeSystem::get()->font;
 
-    add_printable( new PrintableImage( Diary::d->get_icon32(),
+    add_printable( new PrintableImage( Lifeograph::icons->diary_32,
                                        m_margin_x + m_page_w / 2 - 16, m_total_h_cur ));
 
     m_marked_up_text = STR::compose( "<span size='xx-large'>",
