@@ -79,8 +79,8 @@ class Settings
         bool                        state_maximized{ false };
         int                         position_x{ POSITION_NOTSET };
         int                         position_y{ POSITION_NOTSET };
-        int                         position_pane{ PANEPOS_DEFAULT };
-        int                         position_pane_tags{ PANEPOS_TAGS_DEFAULT };
+        int                         position_paned_main{ PANEPOS_DEFAULT };
+        int                         position_paned_extra{ PANEPOS_TAGS_DEFAULT };
 
         std::string                 icon_theme;
         bool                        small_lists{ true };
