@@ -386,10 +386,26 @@ Chart::draw( const Cairo::RefPtr< Cairo::Context >& cr )
         cr->line_to( m_width, s_y_min + i * grid_step_y + 0.5 );
     }
 
+    // y LABELS
+    auto&& layout_ym{ Pango::Layout::create( cr ) };
+
+    cr->set_source_rgb( 0.1, 0.1, 0.1 );
+    cr->move_to( BORDER_LABEL, s_y_min - label_y - OFFSET_LABEL );
+    layout_ym->set_text( STR::format_number( m_v_max ) + " " + m_data.unit );
+    layout_ym->show_in_cairo_context( cr );
+
+    cr->move_to( BORDER_LABEL, m_y_mid / 2 - label_y - OFFSET_LABEL );
+    layout_ym->set_text(
+            STR::format_number( ( m_v_max + m_v_min ) / 2 ) + " " + m_data.unit );
+    layout_ym->show_in_cairo_context( cr );
+
+    cr->move_to( BORDER_LABEL, m_y_max - label_y - OFFSET_LABEL );
+    layout_ym->set_text( STR::format_number( m_v_min ) + " " + m_data.unit );
+    layout_ym->show_in_cairo_context( cr );
+
     // YEAR & MONTH LABELS + VERTICAL LINES
     Date         date_hovered{ m_data.get_start_date() };
     unsigned int year_last{ 0 };
-    auto&&       layout_ym{ Pango::Layout::create( cr ) };
 
     if( ( m_step_start + m_hovered_step ) > 0 )
         m_data.forward_date( date_hovered.m_date, m_step_start + m_hovered_step );
@@ -494,21 +510,6 @@ Chart::draw( const Cairo::RefPtr< Cairo::Context >& cr )
         cr->unset_dash();
     }
 
-    // y LABELS
-    cr->set_source_rgb( 0.1, 0.1, 0.1 );
-    cr->move_to( BORDER_LABEL, s_y_min - label_y - OFFSET_LABEL );
-    layout_ym->set_text( STR::format_number( m_v_max ) + " " + m_data.unit );
-    layout_ym->show_in_cairo_context( cr );
-
-    cr->move_to( BORDER_LABEL, ( m_y_max + s_y_min ) / 2 - label_y - OFFSET_LABEL );
-    layout_ym->set_text(
-            STR::format_number( ( m_v_max + m_v_min ) / 2 ) + " " + m_data.unit );
-    layout_ym->show_in_cairo_context( cr );
-
-    cr->move_to( BORDER_LABEL, m_y_max - label_y - OFFSET_LABEL );
-    layout_ym->set_text( STR::format_number( m_v_min ) + " " + m_data.unit );
-    layout_ym->show_in_cairo_context( cr );
-
     // TOOLTIP
     if( m_flag_widget_hovered && m_hovered_step >= 0 )
     {
