@@ -200,7 +200,8 @@ WidgetTable::on_button_press_event( GdkEventButton* event )
                 m_data.m_f_sort_desc = false;
                 m_data.m_i_col_sort = m_i_col_cur;
             }
-            calculate_and_plot( false );
+            sort_and_plot();
+
         }
         if( m_i_line_cur > 0 )
         {
@@ -612,6 +613,16 @@ WidgetTable::calculate_and_plot( bool flag_emit_changed )
     }
 }
 
+void
+WidgetTable::sort_and_plot()
+{
+    m_i_line_top = 0;
+    m_data.sort_lines();
+
+    update_scrollbar();
+    refresh();
+}
+
 void
 WidgetTable::update_child_widget_visibilities()
 {
