@@ -476,10 +476,6 @@ TextbufferDiary::parse( int p_bgn, int p_end )
     if( p_bgn < 0 )
         p_bgn = 0;
 
-    // COMPLETELY CLEAR THE PARSING REGION
-    clear_links( p_bgn, p_end );
-    remove_all_tags( get_iter_at_offset( p_bgn ), get_iter_at_offset( p_end ) );
-
     update_todo_status();
 
     // DO THE PARSING
@@ -503,6 +499,10 @@ TextbufferDiary::reset( UstringSize bgn, UstringSize end )
 {
     ParserText::reset( bgn, end );
 
+    // COMPLETELY CLEAR THE PARSING REGION
+    clear_links( bgn, end );
+    remove_all_tags( get_iter_at_offset( bgn ), get_iter_at_offset( end ) );
+
     // Following must come after reset as m_pos_para_bgn is reset there
     if( m_p2entry )
     {
