@@ -692,13 +692,6 @@ TextbufferDiaryEdit::set_check( char new_status )
 void
 TextbufferDiaryEdit::set_list_item( char type )
 {
-    // LEGEND for char_lf values
-    //      a: any char
-    //      t: tab
-    //      s: space
-    //      c: check mark such as + or x
-    //      n: new line
-
     if( Lifeograph::is_internal_operations_ongoing() )
         return;
 
@@ -715,11 +708,11 @@ TextbufferDiaryEdit::set_list_item( char type )
 void
 TextbufferDiaryEdit::set_list_item_internal( Gtk::TextIter& it_bgn,
                                              Gtk::TextIter& it_end,
-                                             char type )
+                                             char target_item_type )
 {
     if ( it_bgn == it_end ) // empty line
     {
-        switch( type )
+        switch( target_item_type )
         {
             case '*':
                 it_bgn = insert( it_bgn, "\t• " );
@@ -747,12 +740,19 @@ TextbufferDiaryEdit::set_list_item_internal( Gtk::TextIter& it_bgn,
     auto    it_erase_begin = it_bgn;
     char    item_type{ 0 };    // none
     char    char_lf{ 't' };    // tab
-    while( it_bgn != get_iter_at_offset( offset ) )
+    // LEGEND for char_lf values
+    //      a: any char
+    //      t: tab
+    //      s: space
+    //      c: check mark such as + or x
+    //      n: new line
+
+    while( it_bgn.get_offset() <= offset )
     {
-        switch( it_bgn.get_char() )
+        switch( it_bgn.get_offset() == offset ? 0 : it_bgn.get_char() )
         {
             case '\t':
-                if( char_lf == 't'  || char_lf == '[' )
+                if( char_lf == 't' || char_lf == '[' )
                 {
                     char_lf = '[';  // opening bracket
                     it_erase_begin = it_bgn;
@@ -774,7 +774,7 @@ TextbufferDiaryEdit::set_list_item_internal( Gtk::TextIter& it_bgn,
             case ' ':
                 if( char_lf == 's' ) // separator space
                 {
-                    if( item_type != type )
+                    if( item_type != target_item_type )
                     {
                         it_bgn++;
                         offset -= ( it_bgn.get_offset() - it_erase_begin.get_offset() );
@@ -803,12 +803,12 @@ TextbufferDiaryEdit::set_list_item_internal( Gtk::TextIter& it_bgn,
                 item_type = 0;
                 char_lf = 't';  // tab
                 break;
-            case 0: // end
+            //case 0: // end
             default:
                 if( char_lf == 'a' || char_lf == 't' || char_lf == '[' )
                 {
                     Ustring list_str;
-                    switch( type )
+                    switch( target_item_type )
                     {
                         case '*':
                             list_str = "\t• " ;
@@ -830,12 +830,13 @@ TextbufferDiaryEdit::set_list_item_internal( Gtk::TextIter& it_bgn,
                             break;
                     }
                     it_bgn = insert( it_bgn, list_str );
-                    offset+= list_str.length();
+                    offset += list_str.length();
                 }
                 char_lf = 'n';
                 break;
         }
-        ++it_bgn;
+        if( it_bgn.forward_char() == false )
+            return;
     }
 }
 
@@ -999,7 +1000,7 @@ TextbufferDiaryEdit::open_paragraph_below()
     iter.forward_line();
     iter = insert( iter, "\n" );
 
-    place_cursor( --iter );
+    place_cursor( iter.is_end() ? iter : --iter );
 }
 
 void
@@ -1116,10 +1117,25 @@ TextbufferDiaryEdit::duplicate_paragraphs()
 void
 TextbufferDiaryEdit::insert_comment()
 {
-    auto&& iter{ get_insert()->get_iter() };
-    iter = insert( iter, "[[]]" );
-    iter.backward_chars( 2 );
-    place_cursor( iter );
+    if( get_has_selection() )
+    {
+        Gtk::TextIter it_bgn, it_end;
+        get_selection_bounds( it_bgn, it_end );
+        const auto pos_bgn = it_bgn.get_offset();
+        const auto pos_end = it_end.get_offset() + 4;
+
+        insert( it_end, "]]" );
+        insert( get_iter_at_offset( pos_bgn ), "[[" );
+
+        select_range( get_iter_at_offset( pos_bgn ), get_iter_at_offset( pos_end ) );
+    }
+    else
+    {
+        auto&& iter{ get_insert()->get_iter() };
+        iter = insert( iter, "[[]]" );
+        iter.backward_chars( 2 );
+        place_cursor( iter );
+    }
 }
 
 void
